# -*- coding: utf-8 -*-
#
# Do NOT edit this system file by hand -- use git.
# See "URL to git source" below.
#
# Author:        $Id: Thomas R. Stevenson <aa0026@wayne.edu> $
#
# Last Changed:  $Date: Thu Jan 26 11:02:02 2023 -0500 $
#
# URL to git source: $URL: git@git.wayne.edu:ECS_Projects/ECSpylibs.git $
#
# ECSpylibs

-rw-rw-r--. 1 tom tom 2380 Jan 18 14:55 ecspylibs/buildfunctionlist.py
-rw-rw-r--. 1 tom tom 7651 Jan 18 14:55 ecspylibs/checkservice.py
-rw-rw-r--. 1 tom tom 2679 Jan 18 14:55 ecspylibs/cleanuptempdirs.py
-rwxr-xr-x. 1 tom tom  465 Nov  5  2020 ecspylibs/__init__.py
-rw-rw-r--. 1 tom tom 3670 Jan 18 14:55 ecspylibs/initsetup.py
-rw-rw-r--. 1 tom tom 5357 Jan 18 14:55 ecspylibs/parseemail.py
-rw-rw-r--. 1 tom tom 3264 Jan 18 14:55 ecspylibs/parsexml.py
-rw-rw-r--. 1 tom tom 3644 Jan 18 14:55 ecspylibs/password.py
-rw-rw-r--. 1 tom tom 1751 Jan 18 14:55 ecspylibs/reapchildren.py
-rw-rw-r--. 1 tom tom 3250 Jan 18 14:55 ecspylibs/sendemail.py

The GIT Home can be found [Here][ECSPYLIBS].
The README file can be found [Here][README].
The LICENSE file can be found [Here][LICENSE].
The ChangeLog file can be found [Here][CHANGELOG].
The pyproject.toml file can be found [Here][PYPROJECT].
My contact information can be found [Here][About Me].

[ECSPYLIBS]: https://git.wayne.edu/aa0026/ecspylibs
[README]: https://git.wayne.edu/aa0026/ecspylibs/-/blob/master/README.md
[LICENSE]: https://git.wayne.edu/aa0026/ecspylibs/-/blob/master/LICENSE.txt
[CHANGELOG]: https://git.wayne.edu/aa0026/ecspylibs/-/blob/master/ChangeLog
[PYPROJECT]: https://git.wayne.edu/aa0026/ecspylibs/-/blob/master/pyproject.toml
[About Me]: https://About.Me/Thomas.R.Stevenson
